@@ -23,7 +23,7 @@
 #include "memxor.h"
 
 void *
-gl_memxor (void *restrict dest, const void *restrict src, size_t n)
+memxor (void *restrict dest, const void *restrict src, size_t n)
 {
   char const *s = src;
   char *d = dest;
